Functions
- find_
catcher - Check if an error matches a Catch block and return the target state name.
- should_
retry - Check if we should retry an error based on Retry configuration. Returns the delay in milliseconds if we should retry, or None if retries are exhausted.