pub fn start_execution_from_delivery(
state: &SharedStepFunctionsState,
delivery: &Option<Arc<DeliveryBus>>,
dynamodb_state: &Option<SharedDynamoDbState>,
registry: &Option<SharedServiceRegistry>,
state_machine_arn: &str,
input: &str,
)Expand description
Start a Step Functions execution from a cross-service delivery (e.g. EventBridge).
This is the public entry point used by StepFunctionsDeliveryImpl in the server crate.
It mirrors the logic from StartExecution but without the AWS request/response wrapper.
Start a Step Functions execution from a cross-service delivery (e.g. EventBridge).
This is the public entry point used by StepFunctionsDeliveryImpl in the server crate.
It mirrors the logic from StartExecution but without the AWS request/response wrapper.