execute_state_machine

Function execute_state_machine 

pub async fn execute_state_machine(
    state: SharedStepFunctionsState,
    execution_arn: String,
    definition: String,
    input: Option<String>,
    delivery: Option<Arc<DeliveryBus>>,
    dynamodb_state: Option<SharedDynamoDbState>,
)
Execute a state machine definition with the given input. Updates the execution record in shared state as it progresses.